@@ -79,13 +79,17 @@ systray_draw(widget_t *widget, draw_context_t *ctx,
     }
 
     systray_data_t *d = widget->data;
-    d->height = p->geometry.height;
+
+    if (p->orientation == East)
+        d->height = p->geometry.height;
+    else
+        d->height = p->geometry.width;
 
     /* set wibox orientation */
     /** \todo stop setting that property on each redraw */
     xcb_change_property(globalconf.connection, XCB_PROP_MODE_REPLACE,
                         globalconf.screens.tab[p->ctx.phys_screen].systray.window,
-                        _NET_SYSTEM_TRAY_ORIENTATION, CARDINAL, 32, 1, &orient);
+                        _NET_SYSTEM_TRAY_ORIENTATION, XCB_ATOM_CARDINAL, 32, 1, &orient);
 }
 
 /** Delete a systray widget.
