@@ -117,21 +117,21 @@ textbox_extents(lua_State *L, widget_t *widget)
 {
     textbox_data_t *d = widget->data;
     area_t geometry = d->extents;
-    geometry.width += d->margin.left + d->margin.left;
+    geometry.width += d->margin.left + d->margin.right;
     geometry.height += d->margin.bottom + d->margin.top;
 
     if(d->width)
         geometry.width = d->width;
 
     if(d->height)
-        geometry.width = d->height;
+        geometry.height = d->height;
 
     if(d->bg_image)
     {
         int bgi_height = image_getheight(d->bg_image);
         int bgi_width = image_getwidth(d->bg_image);
         double ratio = d->bg_resize ? (double) geometry.height / bgi_height : 1;
-        geometry.width = MAX(d->extents.width + d->margin.left + d->margin.right, MAX(d->width, bgi_width * ratio));
+        geometry.width = MAX(geometry.width, bgi_width * ratio);
     }
 
     geometry.x = geometry.y = 0;
